PALM-meteo: palmmeteo.vinterp Namespace Reference

PALM-meteo

Functions | Variables
palmmeteo.vinterp Namespace Reference

## Functions
def | interpolator (name)
def | lpad (var)
def | get_vinterp (ztarget, zsource, linear=True, wind=True)
def | get_vinterp_prepared (ztarget, zsource)
def | get_vinterp_metpy (ztarget, zsource)
def | get_vinterp_fortran (ztarget, zsource)

## Variables
dictionary | interpolators = {}

## Function Documentation

## ◆ get_vinterp()

def palmmeteo.vinterp.get_vinterp | ( |  | ztarget,
|  |  | zsource,
|  |  | linear = `True`,
|  |  | wind = `True`
| ) |  |

    Return configured vertical interpolators for given target and source level
    heights. Returns linear interpolator and/or configured wind profile
    interpolator.

## ◆ get_vinterp_fortran()

def palmmeteo.vinterp.get_vinterp_fortran | ( |  | ztarget,
|  |  | zsource
| ) |  |

    Returns a wrapper for the native Fortran interpolator

## ◆ get_vinterp_metpy()

def palmmeteo.vinterp.get_vinterp_metpy | ( |  | ztarget,
|  |  | zsource
| ) |  |

    Returns a wrapper for the MetPy interpolator

## ◆ get_vinterp_prepared()

def palmmeteo.vinterp.get_vinterp_prepared | ( |  | ztarget,
|  |  | zsource
| ) |  |

    Creates Python-based vertical interpolator with prepared weights.
    Accepts 1D or 3D ztarget and zsource (at least 1 must be 3D).
    Extrapolates below zsource, but not above.

## ◆ interpolator()

def palmmeteo.vinterp.interpolator | ( |  | name | ) |

    Decorator for list of interpolators

## ◆ lpad()

def palmmeteo.vinterp.lpad | ( |  | var | ) |

    Pad variable in first dimension by repeating lowest layer twice

## Variable Documentation

## ◆ interpolators

dictionary palmmeteo.vinterp.interpolators = {}